@@ -1,18 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"Fl__Overlay__Window_8H_source.html":[7,0,0,0,78],
-"Fl__PDF__File__Surface_8H_source.html":[7,0,0,0,81],
-"Fl__PNG__Image_8H_source.html":[7,0,0,0,84],
-"Fl__PNM__Image_8H_source.html":[7,0,0,0,85],
-"Fl__Pack_8H_source.html":[7,0,0,0,79],
-"Fl__Paged__Device_8H.html":[7,0,0,0,80],
-"Fl__Paged__Device_8H.html#ad85fd91db75c56dcf6696635c1db0aff":[7,0,0,0,80,2],
-"Fl__Paged__Device_8H_source.html":[7,0,0,0,80],
-"Fl__Paged__Device_8cxx.html":[7,0,0,1,24],
-"Fl__Pixmap_8H_source.html":[7,0,0,0,82],
-"Fl__Plugin_8H_source.html":[7,0,0,0,83],
-"Fl__Positioner_8H_source.html":[7,0,0,0,86],
-"Fl__PostScript_8H.html":[7,0,0,0,87],
 "Fl__PostScript_8H.html#a7961bde9b58e4465fdf4a645b7e270a5":[7,0,0,0,87,2],
 "Fl__PostScript_8H_source.html":[7,0,0,0,87],
 "Fl__Preferences_8H_source.html":[7,0,0,0,88],
@@ -249,5 +236,18 @@ var NAVTREEINDEX2 =
 "classFl__Anim__GIF__Image.html#afde776793388c7628e18200443e84248":[6,0,2,28],
 "classFl__BMP__Image.html":[6,0,4],
 "classFl__BMP__Image.html#a1abb2ebb6ca113fd03a967b66624c868":[6,0,4,0],
-"classFl__BMP__Image.html#af21d8e8fd1cbffd284e98e91f7c3d95a":[6,0,4,1]
+"classFl__BMP__Image.html#af21d8e8fd1cbffd284e98e91f7c3d95a":[6,0,4,1],
+"classFl__Bitmap.html":[6,0,3],
+"classFl__Bitmap.html#a036c2067e5eaf722f55f57e6986d3105":[6,0,3,8],
+"classFl__Bitmap.html#a2fe6a97b247740b5e0a2723818e69504":[6,0,3,11],
+"classFl__Bitmap.html#a3c605ce40b51d1555d2f53c65201aa21":[6,0,3,3],
+"classFl__Bitmap.html#a3d929856c16187cc98cbac70e0b58fe3":[6,0,3,7],
+"classFl__Bitmap.html#a5a4c7fa5582fa336413bba666dae50d9":[6,0,3,2],
+"classFl__Bitmap.html#a5eb102e0ab090a7c547e9349dbe7e943":[6,0,3,1],
+"classFl__Bitmap.html#a5ff5bdc4e093728d84f2fcbce76a4aba":[6,0,3,10],
+"classFl__Bitmap.html#abb9d089d289d990de49b9722fbd57241":[6,0,3,0],
+"classFl__Bitmap.html#ac406f77668a462efe3fb97cd4e7b0405":[6,0,3,9],
+"classFl__Bitmap.html#adbcdda3f20d1f1bc3cbf5c7ad444f1a9":[6,0,3,4],
+"classFl__Bitmap.html#ae8a3b4435c4d09e0038287b74fe255c7":[6,0,3,6],
+"classFl__Bitmap.html#ae9c6de019cd44bf417a350b70c0a103e":[6,0,3,5]
 };
